#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>

#define led1 2
#define led2 0
#define led3 4
#define led4 5
#define led5 14
#define led6 16

//const char* ssid = ""; //SSID aus dem Router
//const char* password = ""; //Passwort für den Zugang zum WLAN

const char* ssid = "FRITZBox7590GI24"; //SSID aus dem Router
const char* password = "22894580214767401850"; //Passwort für den Zugang zum WLAN

ESP8266WebServer server(80); //Port auf welchem der Server laufen soll.

int led1Status = 0;
int led2Status = 0;
int led3Status = 0;
int led4Status = 0;
int led5Status = 0;
int led6Status = 0;

void setup() {
  Serial.begin(9600);

  pinMode(led1, OUTPUT);
  pinMode(led2, OUTPUT);
  pinMode(led3, OUTPUT);
  pinMode(led4, OUTPUT);
  pinMode(led5, OUTPUT);
  pinMode(led6, OUTPUT);

  Serial.print("Aufbau der Verbindung zu: "); //Ausgabe der SSID auf der Seriellen Schnittstelle.
  Serial.println(ssid);

  WiFi.begin(ssid, password); //Initialisieren der Wifi Verbindung.

  while (WiFi.status() != WL_CONNECTED) { //Warten bis die Verbindung aufgebaut wurde.
    delay(500);
    //Einen Punkt auf der Seriellen Schnittstelle ausgeben so das der Benutzer erkennt dass, das Sketch noch läuft.
    Serial.print(".");
  }

  Serial.println("");

  //Bei erfolgreicher Verbindung wird der folgende Text ausgeben.
  Serial.print("Mit ");
  Serial.print(ssid);
  Serial.print(" erfolgreich verbunden!");

  server.begin(); // Starten des Servers.
  Serial.println("Server gestartet"); //Ausgabe auf der Seriellen Schnittstelle das der Server gestartet wurde.

  // Ausgabe der IP Adresse
  Serial.print("Adresse : http://");
  Serial.print(WiFi.localIP());
  Serial.println("/");

  server.on("/leds", callHandleLeds);
}

void callHandleLeds() {
  String led = "";

  for (int i = 0; i < server.args(); i++) {
    //Zuweisen der Schlüssel/Wertepaare
    String parameterName = server.argName(i);
    String parameterValue = server.arg(i);
    //Wenn der Parametername gleich "text" ist dann...
    Serial.println(parameterName);
    Serial.println(parameterValue);
    if (parameterName == "led") {
      led = parameterValue;
      Serial.println(led);
    } if (parameterName == "status") {
      int ledStatus = parameterValue.toInt();
      Serial.println(ledStatus);
      if (led == "smdLed1") {
        led1Status = ledStatus;
      } else if (led == "smdLed2") {
        led2Status = ledStatus;
      } else if (led == "smdLed3") {
        led3Status = ledStatus;
      } else if (led == "smdLed4") {
        led4Status = ledStatus;
      } else if (led == "smdLed5") {
        led5Status = ledStatus;
      } else if (led == "smdLed6") {
        led6Status = ledStatus;
      }
    }

    setLedStatus();
  }
  writeResponse();
}

void setLedStatus() {
  digitalWrite(led1, led1Status == 0 ? HIGH : LOW);
  digitalWrite(led2, led2Status == 0 ? HIGH : LOW);
  digitalWrite(led3, led3Status == 0 ? HIGH : LOW);
  digitalWrite(led4, led4Status == 0 ? HIGH : LOW);
  digitalWrite(led5, led5Status == 0 ? HIGH : LOW);
  digitalWrite(led6, led6Status == 0 ? HIGH : LOW);
}

/**
   Die Funktion gibt den HTML Kopf auf dem Client aus.
   Dieses wird für jeden Respond verwendet.
 **/
void writeResponse() {
  String htmlContent = "";
  //htmlContent +=
  //htmlContent +="HTTP/1.1 200 OK";
  //htmlContent +="Content-Type: text/html";
  //htmlContent +="";
  htmlContent += "<!DOCTYPE HTML>\n";
  htmlContent += "<html>\n";
  htmlContent += "<script type='text/javascript' src='https://code.jquery.com/jquery-3.5.1.min.js'></script>\n";

  htmlContent += "<style>\n";
  htmlContent += "label{width:60px;margin-right:10px;margin-bottom-5px;line-height:30px}\n";
  htmlContent += "fieldset{width:300px;}\n";
  htmlContent += ".active{background-color:#FF6C6C;}\n";
  htmlContent += "</style>\n";
  htmlContent += "<body>\n";
  htmlContent += "<fieldset><legend>SMD LEDs</legend>\n";

  htmlContent += appendLedControlls(1,"smdLed1", led1Status, led1Status == 0 ? "AUS" : "AN" );
  htmlContent += appendLedControlls(2,"smdLed2", led2Status, led2Status == 0 ? "AUS" : "AN" );
  htmlContent += appendLedControlls(3,"smdLed3", led3Status, led3Status == 0 ? "AUS" : "AN" );
  htmlContent += appendLedControlls(4,"smdLed4", led4Status, led4Status == 0 ? "AUS" : "AN" );
  htmlContent += appendLedControlls(5,"smdLed5", led5Status, led5Status == 0 ? "AUS" : "AN" );
  htmlContent += appendLedControlls(6,"smdLed6", led6Status, led6Status == 0 ? "AUS" : "AN" );

  htmlContent += "</fieldset>\n";

  htmlContent += "<script>\n";
  htmlContent += "$(function() {\n";
  htmlContent += "$( '.smdLedBtn' ).click(function() {\n";
  htmlContent += "led = $(this).attr('id');";
  htmlContent += "status = $(this).attr('status');";
  htmlContent += "\n";
  htmlContent += "if(status == 1){ status = 0; } else { status = 1; }\n";
  htmlContent += "url = 'http://192.168.178.50/leds?led='+led+'&status='+status;\n";
  htmlContent += "console.log(url);\n";
  htmlContent += "\n";
  htmlContent += "$.get(url, function( data ) {location.reload();});\n";
  htmlContent += "});\n";
  htmlContent += "});\n";
  htmlContent += "</script>\n";
  htmlContent += "</body></html>\n";

  server.send(200, "text/html", htmlContent);
}

String appendLedControlls(int numb, String id, int ledStatus, String btnText ) {
  String ledControlls = "";
  ledControlls += "<label for = '" + id + "'>"+String(numb,DEC)+"</label>\n";
  ledControlls += "<button id='" + id + "' class='smdLedBtn ";
  if (ledStatus == 0) {
    ledControlls += "'";
  } else {
    ledControlls += "active'";
  }
  ledControlls += " status='" + String(ledStatus, DEC) + "'>";
  ledControlls += btnText;
  ledControlls += "</button><br/>\n";

  return ledControlls;
}

void loop() {
  server.handleClient();
}
